@@ -79,13 +79,10 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
 
         this._maximizeItem = new PopupMenu.PopupMenuItem('');
         this._maximizeItem.connect('activate', () => {
-            if (this._metaWindow.maximized_vertically &&
-                this._metaWindow.maximized_horizontally)
-                this._metaWindow.unmaximize(Meta.MaximizeFlags.HORIZONTAL |
-                                            Meta.MaximizeFlags.VERTICAL);
+            if (this._metaWindow.get_maximized() == Meta.MaximizeFlags.BOTH)
+                this._metaWindow.unmaximize(Meta.MaximizeFlags.BOTH);
             else
-                this._metaWindow.maximize(Meta.MaximizeFlags.HORIZONTAL |
-                                          Meta.MaximizeFlags.VERTICAL);
+                this._metaWindow.maximize(Meta.MaximizeFlags.BOTH);
         });
         this.addMenuItem(this._maximizeItem);
 
@@ -97,7 +94,7 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
                                      this._updateMaximizeItem.bind(this));
         this._updateMaximizeItem();
 
-        this._closeItem = new PopupMenu.PopupMenuItem(_("Close"));
+        this._closeItem = new PopupMenu.PopupMenuItem(_('Close'));
         this._closeItem.connect('activate', () => {
             this._metaWindow.delete(global.get_current_time());
         });
@@ -116,15 +113,15 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
     }
 
     _updateMinimizeItem() {
-        this._minimizeItem.label.text = this._metaWindow.minimized ? _("Unminimize")
-                                                                   : _("Minimize");
+        this._minimizeItem.label.text = this._metaWindow.minimized ?
+            _('Unminimize') : _('Minimize');
     }
 
     _updateMaximizeItem() {
         let maximized = this._metaWindow.maximized_vertically &&
                         this._metaWindow.maximized_horizontally;
-        this._maximizeItem.label.text = maximized ? _("Unmaximize")
-                                                  : _("Maximize");
+        this._maximizeItem.label.text = maximized ?
+            _('Unmaximize') : _('Maximize');
     }
 
     _onDestroy() {
@@ -137,8 +134,11 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
 class WindowTitle {
     constructor(metaWindow) {
         this._metaWindow = metaWindow;
-        this.actor = new St.BoxLayout({ style_class: 'window-button-box',
-                                        x_expand: true, y_expand: true });
+        this.actor = new St.BoxLayout({
+            style_class: 'window-button-box',
+            x_expand: true,
+            y_expand: true
+        });
 
         this._icon = new St.Bin({ style_class: 'window-button-icon' });
         this.actor.add(this._icon);
@@ -188,8 +188,10 @@ class WindowTitle {
         if (app)
             this._icon.child = app.create_icon_texture(ICON_TEXTURE_SIZE);
         else
-            this._icon.child = new St.Icon({ icon_name: 'icon-missing',
-                                             icon_size: ICON_TEXTURE_SIZE });
+            this._icon.child = new St.Icon({
+                icon_name: 'icon-missing',
+                icon_size: ICON_TEXTURE_SIZE
+            });
     }
 
     _onDestroy() {
@@ -210,12 +212,13 @@ class BaseButton {
         this._perMonitor = perMonitor;
         this._monitorIndex = monitorIndex;
 
-        this.actor = new St.Button({ style_class: 'window-button',
-                                     x_fill: true,
-                                     y_fill: true,
-                                     can_focus: true,
-                                     button_mask: St.ButtonMask.ONE |
-                                                  St.ButtonMask.THREE });
+        this.actor = new St.Button({
+            style_class: 'window-button',
+            x_fill: true,
+            y_fill: true,
+            can_focus: true,
+            button_mask: St.ButtonMask.ONE | St.ButtonMask.THREE
+        });
         this.actor._delegate = this;
 
         this.actor.connect('allocation-changed',
@@ -399,37 +402,35 @@ class AppContextMenu extends PopupMenu.PopupMenu {
 
         this._appButton = appButton;
 
-        this._minimizeItem = new PopupMenu.PopupMenuItem(_("Minimize all"));
+        this._minimizeItem = new PopupMenu.PopupMenuItem(_('Minimize all'));
         this._minimizeItem.connect('activate', () => {
-            this._appButton.getWindowList().forEach(w => { w.minimize(); });
+            this._appButton.getWindowList().forEach(w => w.minimize());
         });
         this.addMenuItem(this._minimizeItem);
 
-        this._unminimizeItem = new PopupMenu.PopupMenuItem(_("Unminimize all"));
+        this._unminimizeItem = new PopupMenu.PopupMenuItem(_('Unminimize all'));
         this._unminimizeItem.connect('activate', () => {
-            this._appButton.getWindowList().forEach(w => { w.unminimize(); });
+            this._appButton.getWindowList().forEach(w => w.unminimize());
         });
         this.addMenuItem(this._unminimizeItem);
 
-        this._maximizeItem = new PopupMenu.PopupMenuItem(_("Maximize all"));
+        this._maximizeItem = new PopupMenu.PopupMenuItem(_('Maximize all'));
         this._maximizeItem.connect('activate', () => {
             this._appButton.getWindowList().forEach(w => {
-                w.maximize(Meta.MaximizeFlags.HORIZONTAL |
-                           Meta.MaximizeFlags.VERTICAL);
+                w.maximize(Meta.MaximizeFlags.BOTH);
             });
         });
         this.addMenuItem(this._maximizeItem);
 
-        this._unmaximizeItem = new PopupMenu.PopupMenuItem(_("Unmaximize all"));
+        this._unmaximizeItem = new PopupMenu.PopupMenuItem(_('Unmaximize all'));
         this._unmaximizeItem.connect('activate', () => {
             this._appButton.getWindowList().forEach(w => {
-                w.unmaximize(Meta.MaximizeFlags.HORIZONTAL |
-                             Meta.MaximizeFlags.VERTICAL);
+                w.unmaximize(Meta.MaximizeFlags.BOTH);
             });
         });
         this.addMenuItem(this._unmaximizeItem);
 
-        let item = new PopupMenu.PopupMenuItem(_("Close all"));
+        let item = new PopupMenu.PopupMenuItem(_('Close all'));
         item.connect('activate', () => {
             this._appButton.getWindowList().forEach(w => {
                 w.delete(global.get_current_time());
@@ -443,10 +444,10 @@ class AppContextMenu extends PopupMenu.PopupMenu {
         this._minimizeItem.actor.visible = windows.some(w => !w.minimized);
         this._unminimizeItem.actor.visible = windows.some(w => w.minimized);
         this._maximizeItem.actor.visible = windows.some(w => {
-            return !(w.maximized_horizontally && w.maximized_vertically);
+            return w.get_maximized() != Meta.MaximizeFlags.BOTH;
         });
         this._unmaximizeItem.actor.visible = windows.some(w => {
-            return w.maximized_horizontally && w.maximized_vertically;
+            return w.get_maximized() == Meta.MaximizeFlags.BOTH;
         });
 
         super.open(animate);
@@ -463,21 +464,29 @@ class AppButton extends BaseButton {
         let stack = new St.Widget({ layout_manager: new Clutter.BinLayout() });
         this.actor.set_child(stack);
 
-        this._singleWindowTitle = new St.Bin({ x_expand: true,
-                                               y_fill: true,
-                                               x_align: St.Align.START });
+        this._singleWindowTitle = new St.Bin({
+            x_expand: true,
+            y_fill: true,
+            x_align: St.Align.START
+        });
         stack.add_actor(this._singleWindowTitle);
 
-        this._multiWindowTitle = new St.BoxLayout({ style_class: 'window-button-box',
-                                                    x_expand: true });
+        this._multiWindowTitle = new St.BoxLayout({
+            style_class: 'window-button-box',
+            x_expand: true
+        });
         stack.add_actor(this._multiWindowTitle);
 
-        this._icon = new St.Bin({ style_class: 'window-button-icon',
-                                  child: app.create_icon_texture(ICON_TEXTURE_SIZE) });
+        this._icon = new St.Bin({
+            style_class: 'window-button-icon',
+            child: app.create_icon_texture(ICON_TEXTURE_SIZE)
+        });
         this._multiWindowTitle.add(this._icon);
 
-        let label = new St.Label({ text: app.get_name(),
-                                   y_align: Clutter.ActorAlign.CENTER });
+        let label = new St.Label({
+            text: app.get_name(),
+            y_align: Clutter.ActorAlign.CENTER
+        });
         this._multiWindowTitle.add(label);
         this._multiWindowTitle.label_actor = label;
 
@@ -538,7 +547,7 @@ class AppButton extends BaseButton {
         let rect = this._getIconGeometry();
 
         let windows = this.app.get_windows();
-        windows.forEach(w => { w.set_icon_geometry(rect); });
+        windows.forEach(w => w.set_icon_geometry(rect));
     }
 
     getWindowList() {
@@ -638,21 +647,26 @@ class AppButton extends BaseButton {
 let WorkspaceIndicator = GObject.registerClass(
 class WorkspaceIndicator extends PanelMenu.Button {
     _init() {
-        super._init(0.0, _("Workspace Indicator"), true);
+        super._init(0.0, _('Workspace Indicator'), true);
         this.setMenu(new PopupMenu.PopupMenu(this, 0.0, St.Side.BOTTOM));
         this.add_style_class_name('window-list-workspace-indicator');
         this.menu.actor.remove_style_class_name('panel-menu');
 
-        let container = new St.Widget({ layout_manager: new Clutter.BinLayout(),
-                                        x_expand: true, y_expand: true });
+        let container = new St.Widget({
+            layout_manager: new Clutter.BinLayout(),
+            x_expand: true,
+            y_expand: true
+        });
         this.add_actor(container);
 
         let workspaceManager = global.workspace_manager;
 
         this._currentWorkspace = workspaceManager.get_active_workspace().index();
-        this.statusLabel = new St.Label({ text: this._getStatusText(),
-                                          x_align: Clutter.ActorAlign.CENTER,
-                                          y_align: Clutter.ActorAlign.CENTER });
+        this.statusLabel = new St.Label({
+            text: this._getStatusText(),
+            x_align: Clutter.ActorAlign.CENTER,
+            y_align: Clutter.ActorAlign.CENTER
+        });
         container.add_actor(this.statusLabel);
 
         this.workspacesItems = [];
@@ -761,23 +775,27 @@ class WindowList {
         this._perMonitor = perMonitor;
         this._monitor = monitor;
 
-        this.actor = new St.Widget({ name: 'panel',
-                                     style_class: 'bottom-panel solid',
-                                     reactive: true,
-                                     track_hover: true,
-                                     layout_manager: new Clutter.BinLayout() });
+        this.actor = new St.Widget({
+            name: 'panel',
+            style_class: 'bottom-panel solid',
+            reactive: true,
+            track_hover: true,
+            layout_manager: new Clutter.BinLayout()
+        });
         this.actor.connect('destroy', this._onDestroy.bind(this));
 
         let box = new St.BoxLayout({ x_expand: true, y_expand: true });
         this.actor.add_actor(box);
 
         let layout = new Clutter.BoxLayout({ homogeneous: true });
-        this._windowList = new St.Widget({ style_class: 'window-list',
-                                           reactive: true,
-                                           layout_manager: layout,
-                                           x_align: Clutter.ActorAlign.START,
-                                           x_expand: true,
-                                           y_expand: true });
+        this._windowList = new St.Widget({
+            style_class: 'window-list',
+            reactive: true,
+            layout_manager: layout,
+            x_align: Clutter.ActorAlign.START,
+            x_expand: true,
+            y_expand: true
+        });
         box.add(this._windowList, { expand: true });
 
         this._windowList.connect('style-changed', () => {
@@ -805,10 +823,12 @@ class WindowList {
         this._menuManager = new PopupMenu.PopupMenuManager(this);
         this._menuManager.addMenu(this._workspaceIndicator.menu);
 
-        Main.layoutManager.addChrome(this.actor, { affectsStruts: true,
-                                                   trackFullscreen: true });
+        Main.layoutManager.addChrome(this.actor, {
+            affectsStruts: true,
+            trackFullscreen: true
+        });
         Main.uiGroup.set_child_above_sibling(this.actor, Main.layoutManager.panelBox);
-        Main.ctrlAltTabManager.addGroup(this.actor, _("Window List"), 'start-here-symbolic');
+        Main.ctrlAltTabManager.addGroup(this.actor, _('Window List'), 'start-here-symbolic');
 
         this.actor.width = this._monitor.width;
         this.actor.connect('notify::height', this._updatePosition.bind(this));
@@ -989,8 +1009,8 @@ class WindowList {
         if (!Main.keyboard.actor)
             return;
 
-        let anchorY = Main.overview.visible ? 0 : this.actor.height;
-        Main.keyboard.actor.anchor_y = anchorY;
+        let translationY = Main.overview.visible ? 0 : this.actor.height;
+        Main.keyboard.actor.translation_y = -translationY;
     }
 
     _onAppStateChanged(appSys, app) {
@@ -1205,7 +1225,7 @@ class Extension {
     }
 
     _buildWindowLists() {
-        this._windowLists.forEach(list => { list.actor.destroy(); });
+        this._windowLists.forEach(list => list.actor.destroy());
         this._windowLists = [];
 
         let showOnAllMonitors = this._settings.get_boolean('show-on-all-monitors');
